@@ -1,8 +1,6 @@
-use dioxus_core as dioxus;
 use dioxus_core::prelude::*;
 use dioxus_core_macro::*;
 use dioxus_html as dioxus_elements;
-use wasm_bindgen_test::wasm_bindgen_test;
 use web_sys::window;
 
 fn app(cx: Scope) -> Element {
@@ -51,7 +49,7 @@ fn main() {
     let _ = dom.rebuild();
 
     let pre = dioxus_ssr::pre_render_vdom(&dom);
-    log::debug!("{}", pre);
+    log::trace!("{}", pre);
 
     // set the inner content of main to the pre-rendered content
     window()
